==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/InstanceInvokeEdgesPred.h <==
// public class soot.jimple.toolkits.callgraph.InstanceInvokeEdgesPred

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff9aee3f1db4a3d8 soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred_H_
#define _JC_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$method$want$6d4f4c7f183187ef(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$method_info$want$6d4f4c7f183187ef;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods {
	jboolean	(*want$6d4f4c7f183187ef)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods	soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs {
    _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs	soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs	soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object {
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/InstanceInvokeEdgesPred.h <==
// public class soot.jimple.toolkits.callgraph.InstanceInvokeEdgesPred

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff9aee3f1db4a3d8 soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred_H_
#define _JC_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$method$want$6d4f4c7f183187ef(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$method_info$want$6d4f4c7f183187ef;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods {
	jboolean	(*want$6d4f4c7f183187ef)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object *, struct _jc_soot_jimple_toolkits_callgraph_Edge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vmethods	soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs {
    _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_refs	soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$sub_nonrefs	soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$object {
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$vtype _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_InstanceInvokeEdgesPred_H_ */
